.. highlight:: shell

.. _zfit_installation:

============
Installation
============


Stable release
--------------

To install the newest stable version of zfit, use pip and run this command in your terminal (recommended to do inside a
`conda <https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html>`_ or
`virtualenv <https://virtualenv.pypa.io/en/latest/>`_ virtual environment):

.. code-block:: console

    $ pip install zfit

This is the preferred method to install zfit, as it will always install the most recent stable release.




Cutting edge version
-----------------------

The cutting edge development version (unstable) can be installed from the `Github repo`_ with

.. code-block:: console

    $ pip install git+https://github.com/zfit/zfit



You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/zfit/zfit



.. _Github repo: https://github.com/zfit/zfit
.. _tarball: https://github.com/zfit/zfit/tarball/master
